@@ -1,4 +1,4 @@
-/* $Id: libgnomeuimm.h,v 1.6 2004/03/30 21:17:56 murrayc Exp $ */
+/* $Id: libgnomeuimm.h 644 2004-04-06 21:16:41Z mxpxpod $ */
 /* libgnomeuimm - a C++ wrapper for libgnomeui
  *
  * Copyright 1999-2001 Free Software Foundation
@@ -53,6 +53,8 @@ extern const int libgnomeuimm_micro_version;
 #include <libgnomeuimm/init.h>
 #include <libgnomeuimm/pixmap-entry.h>
 #include <libgnomeuimm/stock.h>
+#include <libgnomeuimm/thumbnail.h>
+#include <libgnomeuimm/icon-lookup.h>
 
 
 #endif /* #ifndef LIBGNOMEUIMM_H */
